@@ -372,6 +372,58 @@ def test_stream_pwatched_cleanup():
     assert (actual == expected).all()
 
 
+def test_device_stream_pwatched_cleanup():
+    stream_pwatched_data = {
+        "version": 1,
+        "data": {
+            "autoplay": {"attempts": 1, "watched": 1},
+            "ch_swtch": {"attempts": 2, "watched": 0},
+        },
+    }
+    stream_pwatched = features_pb2_v1.StreamPWatched()
+    ProtoParseDict(js_dict=stream_pwatched_data, message=stream_pwatched)
+    stream = {"PWATCHED#24H#TV": stream_pwatched}
+    out = {}
+    utils.device_watched_count_cleanups(
+        stream=stream,
+        entry_contexts=["autoplay", "ch_swtch", "sel_thumb"],
+        device_type="TV",
+        out=out,
+    )
+    expected = pd.Series(
+        {
+            "STREAM_AUTOPLAY_TV_24H_TOTAL_ATTEMPTS": 1,
+            "STREAM_AUTOPLAY_TV_24H_TOTAL_WATCHED": 1,
+            "STREAM_CH_SWTCH_TV_24H_TOTAL_ATTEMPTS": 2,
+            "STREAM_CH_SWTCH_TV_24H_TOTAL_WATCHED": 0,
+            "STREAM_SEL_THUMB_TV_24H_TOTAL_ATTEMPTS": 0,
+            "STREAM_SEL_THUMB_TV_24H_TOTAL_WATCHED": 0,
+        }
+    )
+    actual = pd.Series(out).loc[expected.index]
+    assert (actual == expected).all()
+    stream = {"PWATCHED#24H#MOBILE": stream_pwatched}
+    out = {}
+    utils.device_watched_count_cleanups(
+        stream=stream,
+        entry_contexts=["autoplay", "ch_swtch", "sel_thumb"],
+        device_type="MOBILE",
+        out=out,
+    )
+    expected = pd.Series(
+        {
+            "STREAM_AUTOPLAY_MOBILE_24H_TOTAL_ATTEMPTS": 1,
+            "STREAM_AUTOPLAY_MOBILE_24H_TOTAL_WATCHED": 1,
+            "STREAM_CH_SWTCH_MOBILE_24H_TOTAL_ATTEMPTS": 2,
+            "STREAM_CH_SWTCH_MOBILE_24H_TOTAL_WATCHED": 0,
+            "STREAM_SEL_THUMB_MOBILE_24H_TOTAL_ATTEMPTS": 0,
+            "STREAM_SEL_THUMB_MOBILE_24H_TOTAL_WATCHED": 0,
+        }
+    )
+    actual = pd.Series(out).loc[expected.index]
+    assert (actual == expected).all()
+
+
 def test_stream_global_pselect_cleanup():
     stream_pselect_data = {
         "version": 1,
